@@ -128,7 +128,7 @@ sub get_files
     my $path            = $extract->value( 'module_source' ); 
     my $found           = dircopy $path, '.';
     
-    print "# Copied: $found files from '$path'";
+    print "# Processed: $found files/dirs from '$path'";
 
     my $expect          = @$filz + @$dirz + 1;
 
